@@ -87,11 +87,12 @@ class EB_ScaLAPACK(ConfigureMake):
         """Build ScaLAPACK using make after setting make options."""
 
         # MPI compiler commands
+        known_mpi_libs = [toolchain.OPENMPI, toolchain.MVAPICH2, toolchain.MPICH, toolchain.QLOGICMPI]  #@UndefinedVariable
         if os.getenv('MPICC') and os.getenv('MPIF77') and os.getenv('MPIF90'):
             mpicc = os.getenv('MPICC')
             mpif77 = os.getenv('MPIF77')
             mpif90 = os.getenv('MPIF90')
-        elif self.toolchain.mpi_family() in [toolchain.OPENMPI, toolchain.MVAPICH2, toolchain.MPICH]:  #@UndefinedVariable
+        elif self.toolchain.mpi_family() in known_mpi_libs:
             mpicc = 'mpicc'
             mpif77 = 'mpif77'
             mpif90 = 'mpif90'
@@ -161,7 +162,7 @@ class EB_ScaLAPACK(ConfigureMake):
         else:
 
             # determine interface
-            if self.toolchain.mpi_family() in [toolchain.OPENMPI, toolchain.MVAPICH2, toolchain.MPICH]:  #@UndefinedVariable
+            if self.toolchain.mpi_family() in known_mpi_libs:
                 interface = 'Add_'
             else:
                 self.log.error("Don't know which interface to pick for the MPI library being used.")
